@@ -70,29 +70,25 @@ around run => sub ( $orig, $self, $req ) {
         $self->{ext_app_namespace} => $self->{path},
     };
 
-    $req->authenticate(
-        sub ($auth) {
-            $auth->extdirect_map(
-                undef,
-                sub ($api_map) {
-                    my $data = {
-                        INDEX     => { title => $self->extjs_app_title },
-                        resources => $resources,
-                        ext       => {
-                            api_map => $api_map ? to_json($api_map)->$* : undef,
-                            loader_path    => mark_raw( to_json( $loader_path, readable => $devel )->$* ),
-                            app_namespace  => $self->{ext_app_namespace},
-                            viewport_class => "$self->{ext_app_namespace}.Viewport",
-                        },
-                    };
+    $self->{app}->{api}->{map}->extdirect_map(
+        undef, undef,
+        sub ($api_map) {
+            my $data = {
+                INDEX => {    #
+                    title => $self->extjs_app_title
+                },
+                resources => $resources,
+                ext       => {
+                    api_map => $api_map ? to_json($api_map)->$* : undef,
+                    loader_path    => mark_raw( to_json( $loader_path, readable => $devel )->$* ),
+                    app_namespace  => $self->{ext_app_namespace},
+                    viewport_class => "$self->{ext_app_namespace}.Viewport",
+                },
+            };
 
-                    my $index = P->tmpl->render( 'extjs/index.html', $data );
+            my $index = P->tmpl->render( 'extjs/index.html', $data );
 
-                    $req->( 200, [ 'Content-Type' => 'text/html; charset=UTF-8' ], $index )->finish;
-
-                    return;
-                }
-            );
+            $req->( 200, [ 'Content-Type' => 'text/html; charset=UTF-8' ], $index )->finish;
 
             return;
         }
